<template>
  <a-card
    :bordered='false'
    :class="'cust-erp-sub-tab'"
  >
    <!-- 查询区域 -->
    <div class='table-page-search-wrapper'>
      <a-form
        layout='inline'
        @keyup.enter.native='searchQuery'
      >
        <a-row :gutter='24'>
        </a-row>
      </a-form>
    </div>
    <div>
      <a-table
        ref='table'
        size='middle'
        bordered
        rowKey='id'
        :scroll="{ x: 'calc(1400px + 50%)', y: 900 }"
        :columns='columns'
        :dataSource='dataSource'
        :pagination='ipagination'
        :loading='loading'
        @change='handleTableChange'

      >
      </a-table>
    </div>


  </a-card>
</template>

<script>
import { JeecgListMixin } from '@/mixins/JeecgListMixin'
import { getAction } from '@/api/manage'

export default {
  name: 'EquipmentUnloadingReturnDetail',
  mixins: [JeecgListMixin],
  components: {},
  props: {

    equipmentUnloadingId: {
      type: String,
      default: '',
      required: false
    }
  },
  watch: {
    equipmentUnloadingId: {
      immediate: true,
      handler(val) {
        if (!this.equipmentUnloadingId) {
          this.clearList()
        } else {
          this.queryParam['equipmentUnloadingId'] = val
          this.queryParam['delFlag'] = 0
          this.loadData(1)
        }
      }
    }
  },
  data() {
    return {
      // disableMixinCreated: true,
      // originTargetKeys: [],
      // 表头
      disableMixinCreated: true,
      columns: [
        {
          title: '#',
          dataIndex: '',
          key: 'rowIndex',
          width: 50,
          align: 'center',
          customRender: function(t, r, index) {
            return parseInt(index) + 1
          }
        },
        {
          title: '设备编码',
          align: 'center',
          dataIndex: 'equipmentNum'
        },
        {
          title: '设备名称',
          align: 'center',
          dataIndex: 'equipmentName'

        },
        {
          title: '规格',
          align: 'center',
          dataIndex: 'model'

        },
        {
          title: '型号',
          align: 'center',
          dataIndex: 'specification'

        },
        {
          title: '技术状态',
          align: 'center',
          dataIndex: 'technicalStatus'

        },
        {
          title: '责任班组',
          align: 'center',
          dataIndex: 'responsibilityTeamName'

        },
        {
          title: '责任人',
          align: 'center',
          dataIndex: 'responsibilityUserName'

        },
        {
          title: '实际借领日期',
          align: 'center',
          dataIndex: 'actualBorrowDate'
        },
        {
          title: '实际归还日期',
          align: 'center',
          dataIndex: 'actualReturnDate'
        }

      ],
      url: {
        list: '/eam/equipmentUnloadingReturnDetail/getEquipmentUnloadingReturnDetailList'
      }
    }
  },
  created() {
  },
  computed: {},
  methods: {
    clearList() {
      this.dataSource = []
      this.selectedRowKeys = []
      this.ipagination.current = 1
    },
    loadData(arg) {
      if (!this.url.list) {
        this.$message.error('请设置url.list属性!')
        return
      }
      //加载数据 若传入参数1则加载第一页的内容
      if (arg === 1) {
        this.ipagination.current = 1
      }
      var params = this.getQueryParams()//查询条件
      this.loading = true
      // this.originTargetKeys = [];
      getAction(this.url.list, params).then((res) => {
        if (res.success) {

          this.dataSource = res.result.records || res.result
          if (res.result.total) {
            this.ipagination.total = res.result.total
          } else {
            this.ipagination.total = 0
          }
          //update-end---author:zhangyafei    Date:20201118  for：适配不分页的数据列表------------
        } else {
          this.$message.warning(res.message)
        }
      }).finally(() => {
        this.loading = false
      })
    }


  }
}
</script>
<style scoped>
@import '~@assets/less/common.less';
</style>
